import matplotlib.pyplot as plt
import numpy as np
plt.close()

KA1=10**-1.8
KA2=10**-7.2

def pourcentageAH2(h):
    return 100/(1+KA1/h+KA1*KA2/h**2)

def pourcentageAH(h):
    return 100/(1+KA2/h+h/KA1)


def pourcentageA(h):
    return 100/(1+h/KA2+h**2/KA1*KA2)

def croisement(A,B):
    """A et B sont 2 listes
    Renvoie la position dans les listes à partir duquel
    A et B se croisent"""
    if A[0]>B[0]:
        i=1
        while A[i]>B[i]:
            i+=1
        return i
    else:
        i=1
        while A[i]<B[i]:
            i+=1
        return i

pH=np.linspace(0,14,1000)

pAH2=pourcentageAH2(10**(-pH))
pAH=pourcentageAH(10**(-pH))
pA=pourcentageA(10**(-pH))

pKA1=pH[croisement(pAH2,pAH)]
pKA2=pH[croisement(pA,pAH)]

print(pKA1,pKA2)


plt.plot(pH,pAH2,'-b', label='pourcentage en H$_2$SO$_3$')
plt.plot(pH,pAH,'-r', label='pourcentage en HSO$_3^-$')
plt.plot(pH,pA,'-g', label='pourcentage en SO$_3^{2-}$')
plt.legend()
plt.xlabel('pH')
plt.ylabel('% en espèces chimiques')
plt.plot()
plt.show()